import React, { useState, useEffect } from 'react';
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
import Home from './Home';
import About from './About';
import Insights from './Insights';
import Navbar from './Navbar';
import LoginPage from './LoginPage';
import RegisterPage from './RegisterPage';

function App() {
  const [isLoggedIn, setIsLoggedIn] = useState(false);

  useEffect(() => {
    // Assume token is stored in localStorage after successful login/registration
    const token = localStorage.getItem('token');
    if (token) {
      setIsLoggedIn(true);
    }
  }, []);

  const handleLoginSuccess = () => {
    setIsLoggedIn(true);
  };

  const handleRegistrationSuccess = () => {
    setIsLoggedIn(true);
  };

  return (
    <Router>
      <Navbar />
      <Routes>
        {/* Redirect to home if user is already logged in */}
        <Route path="/login" element={!isLoggedIn ? <LoginPage onLoginSuccess={handleLoginSuccess} /> : <Navigate replace to="/home" />} />
        <Route path="/register" element={!isLoggedIn ? <RegisterPage onRegistrationSuccess={handleRegistrationSuccess} /> : <Navigate replace to="/home" />} />

        {/* Protected routes that require user to be logged in */}
        <Route path="/about" element={isLoggedIn ? <About /> : <Navigate replace to="/login" />} />
        <Route path="/insights" element={isLoggedIn ? <Insights /> : <Navigate replace to="/login" />} />
        <Route path="/home" element={isLoggedIn ? <Home /> : <Navigate replace to="/login" />} />

        {/* Default route */}
        <Route path="/" element={<Navigate replace to={isLoggedIn ? "/home" : "/register"} />} />
        <Route path="*" element={<Navigate replace to={isLoggedIn ? "/home" : "/register"} />} />
      </Routes>
    </Router>
  );
}

export default App;
