// LoginPage.js
import React, { useState } from 'react';
import { useNavigate, Link } from 'react-router-dom';
import { loginStudent, loginTeacher } from '../api/api'; // Make sure the path is correct

function LoginPage({ onLoginSuccess }) {
  const [credentials, setCredentials] = useState({
    username: '',
    password: '',
    role: 'student', // Default role is set to student
  });
  const navigate = useNavigate();

  const handleLogin = async (event) => {
    event.preventDefault();
    try {
      const response = credentials.role === 'student'
        ? await loginStudent(credentials)
        : await loginTeacher(credentials);

      // Assuming the response includes some user data and a token
      if (typeof onLoginSuccess === 'function') {
        onLoginSuccess(response.user, response.token);
      } else {
        console.warn('onLoginSuccess is not provided as a function');
        navigate('/home'); // Fallback navigation if onLoginSuccess is not provided
      }
    } catch (error) {
      alert('Login failed: ' + (error.response?.data?.message || error.message));
    }
  };

  const handleChange = (e) => {
    const { name, value } = e.target;
    setCredentials(prevCredentials => ({ ...prevCredentials, [name]: value }));
  };

  return (
    <div className="flex items-center justify-center h-screen bg-gray-200">
      <div className="bg-white shadow-md rounded px-8 pt-6 pb-8 mb-4 flex flex-col">
        <h1 className="mb-6 text-2xl font-bold text-center">O Level Maths Tutor</h1>
        <form onSubmit={handleLogin} className="flex flex-col space-y-4">
          <label htmlFor="role" className="text-gray-700">I am a:</label>
          <select
            id="role"
            name="role"
            value={credentials.role}
            onChange={handleChange}
            required
            className="mb-4 p-2 border border-gray-300 rounded shadow"
          >
            <option value="student">Student</option>
            <option value="teacher">Teacher</option>
          </select>
          <label htmlFor="username" className="text-gray-700">Username:</label>
          <input
            id="username"
            name="username"
            type="text"
            value={credentials.username}
            onChange={handleChange}
            required
            className="p-2 border border-gray-300 rounded shadow"
          />
          <label htmlFor="password" className="text-gray-700">Password:</label>
          <input
            id="password"
            name="password"
            type="password"
            value={credentials.password}
            onChange={handleChange}
            required
            className="p-2 border border-gray-300 rounded shadow"
          />
          <button
            type="submit"
            className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded transition duration-200 ease-in-out"
          >
            Login
          </button>
          <p className="text-center">
            Don't have an account yet?{' '}
            <Link to="/" className="text-blue-600 hover:text-blue-800 transition duration-200 ease-in-out">
              Register here
            </Link>
          </p>
        </form>
      </div>
    </div>
  );
}

export default LoginPage;
