// src/components/RegisterPage.js
import React, { useState } from 'react';
import { Link } from 'react-router-dom'; 
import { registerStudent, registerTeacher } from '../api/api'; // Adjusted import path

    const RegisterPage = () => {
    const [userData, setUserData] = useState({
        username: '',
        password: '',
        role: 'student', // default role
    });

    const handleChange = (e) => {
        setUserData({ ...userData, [e.target.name]: e.target.value });
    };

    const handleSubmit = async (e) => {
        e.preventDefault();
        try {
        if (userData.role === 'student') {
            await registerStudent({ username: userData.username, password: userData.password });
        } else {
            await registerTeacher({ username: userData.username, password: userData.password });
        }
        alert('Registration successful');
        } catch (error) {
        alert(error.message);
        }
    };

    return (
        <div className="flex items-center justify-center h-screen bg-gray-200">
        <div className="bg-white shadow-md rounded px-8 pt-6 pb-8 mb-4 flex flex-col">
            <h1 className="mb-6 text-2xl font-bold text-center">O Level Maths Tutor</h1>
            <form onSubmit={handleSubmit} className="flex flex-col">
            <label htmlFor="username" className="mb-2 text-gray-700">Username:</label>
            <input
                id="username"
                name="username"
                type="text"
                value={userData.username}
                onChange={handleChange}
                placeholder="Username"
                required
                className="mb-4 p-2 border border-gray-300 rounded shadow"
            />
            <label htmlFor="password" className="mb-2 text-gray-700">Password:</label>
            <input
                id="password"
                name="password"
                type="password"
                value={userData.password}
                onChange={handleChange}
                placeholder="Password"
                required
                className="mb-4 p-2 border border-gray-300 rounded shadow"
            />
            <label htmlFor="role" className="mb-2 text-gray-700">Role:</label>
            <select
                id="role"
                name="role"
                value={userData.role}
                onChange={handleChange}
                className="mb-6 p-2 border border-gray-300 rounded shadow"
            >
                <option value="student">Student</option>
                <option value="teacher">Teacher</option>
            </select>
            <button
            type="submit"
            className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded transition duration-200 ease-in-out"
            >
                Register
            </button>
            <p className="text-center">
                Already have an account?{' '}
                <Link to="/login" className="text-blue-600 hover:text-blue-700">
                Login here
                </Link>
            </p>
            </form>
        </div>
        </div>
    );
};

export default RegisterPage;